@@ -163,6 +163,7 @@ QTUM = Coin("QTUM")
 QUICK = Coin("QUICK")
 RAD = Coin("RAD")
 RADAR = Coin("RADAR")
+RARE = Coin("RARE")
 RARI = Coin("RARI")
 RAY = Coin("RAY")
 REEF = Coin("REEF")
@@ -182,6 +183,7 @@ SGB = Coin("SGB")
 SHIB = Coin("SHIB")
 SKL = Coin("SKL")
 SLP = Coin("SLP")
+SNT = Coin("SNT")
 SNX = Coin("SNX")
 SOL = Coin("SOL")
 SPELL = Coin("SPELL")
